import axios from 'axios';
import { useState } from 'react';

var configureAuth = function configureAuth(params) {
  axios.defaults.params = params;
};

var useAxios = function useAxios(configuration) {
  var domains = configuration.domains;
  var instance = axios.create({
    baseURL: domains.appCode
  });

  var _useState = useState(undefined),
      data = _useState[0],
      setData = _useState[1];

  var _useState2 = useState(false),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = useState(undefined),
      error = _useState3[0],
      setError = _useState3[1];

  var _useState4 = useState(undefined),
      response = _useState4[0],
      setResponse = _useState4[1];

  instance.interceptors.request.use(function (config) {
    var params = config.params;
    setLoading(true);
    setError(undefined);

    if (params.apiKey || params.token) {
      config.baseURL = domains.apiKey;
    }

    return config;
  }, function (error) {
    return Promise.reject(error);
  });
  instance.interceptors.response.use(function (res) {
    setLoading(false);
    setResponse(res);
    setData(res.data);
    return res;
  }, function (err) {
    setLoading(false);
    setError(err);
    return err;
  });
  return [{
    data: data,
    loading: loading,
    error: error,
    response: response
  }, function (params) {
    return instance.get('', {
      params: params
    });
  }];
};

/**
 * Submit an address to request the corresponding geocoordinates.
 *
 * Addresses may use structured input or free-form search strings with complete or partial address information.
 *
 * The more detailed the address you submit, the higher the potential match accuracy.
 */

var useForwardGeocoding = function useForwardGeocoding() {
  return useAxios({
    domains: {
      apiKey: 'https://geocoder.ls.hereapi.com/6.2/geocode.json',
      appCode: 'https://geocoder.api.here.com/6.2/geocode.json'
    }
  });
};

/**
 * Submit a geocoordinate and an optional radius to request the corresponding address.
 */

var useReverseGeocoding = function useReverseGeocoding() {
  return useAxios({
    domains: {
      apiKey: 'https://reverse.geocoder.ls.hereapi.com/6.2/reversegeocode.json',
      appCode: 'https://reverse.geocoder.api.here.com/6.2/reversegeocode.json'
    }
  });
};

/**
 * Get better search suggestions for your addresses with fewer keystrokes.
 */

var useAutocomplete = function useAutocomplete() {
  return useAxios({
    domains: {
      apiKey: 'https://autocomplete.geocoder.ls.hereapi.com/6.2/suggest.json',
      appCode: 'https://autocomplete.geocoder.api.here.com/6.2/suggest.json'
    }
  });
};

/**
 * Give insights into real-time weather forecasts, alerts, and astronomical info for any location.
 */

var useWeather = function useWeather() {
  return useAxios({
    domains: {
      appCode: 'https://weather.api.here.com/weather/1.0/report.json',
      apiKey: 'https://weather.ls.hereapi.com/weather/1.0/report.json'
    }
  });
};

/**
 * Provides you a lists of suggested search terms, instants results and refined search links related to a given (partial) search term and location context.
 * This is used to help users save time, iterate on their searches, and get the results.
 */

var usePlacesAutosuggest = function usePlacesAutosuggest() {
  return useAxios({
    domains: {
      apiKey: 'https://places.ls.hereapi.com/places/v1/autosuggest',
      appCode: 'https://places.api.here.com/places/v1/autosuggest'
    }
  });
};

export { configureAuth as configureAuthentication, useAutocomplete, useForwardGeocoding, usePlacesAutosuggest, useReverseGeocoding, useWeather };
//# sourceMappingURL=use-here-api.esm.js.map
